@@ -1,8 +1,7 @@
 import argparse
-import os
 import sys
 
-from .core.aws.eks.aws_eks_runner import AWSEKSRunner
+from .resource_finder import finder
 
 
 def main():
@@ -18,11 +17,11 @@ def main():
 
     print("Sek - Runtime Cloud Security Scanning\n-----")
     print("Cloud: " + CLOUD + " - Resource: " + RESOURCE + " - Name: " + NAME + "\n-----")
+    print("Scan\n-----")
     
-    if ( CLOUD == "aws" or CLOUD == "AWS" ) and ( RESOURCE == "eks" or RESOURCE == "EKS" ):
-        print("Scan\n-----")
-        runner = AWSEKSRunner(NAME)
-    else:
+    runner = finder(CLOUD, RESOURCE, NAME)
+
+    if runner is False:
         print("No Cloud / Resource match. See: https://github.com/njgibbon/sek/tree/main/checks")
         sys.exit(1)
 
